/* Program name: SRDMail.CMD 7.10 29/11/97
Application name: PMMail profile for SR/2.
Author: Michel SUCH  Email: msuch@ibm.net.

Purpose:
This program is a rexx exit for PMMail interfacing with SR/2.
When pmmail runs in background, it will prompt the user
each time a message is received, with
the user's name and the message's subject.
It must be used as a receive exit.
To install it:
Copy it to the directory containing PMMAIL.EXE;
Open PMMail;
Choose account in the menu of the main window;
Then, open utilities settings and choose Rexx tab;
Check the message receive exit checkbox;
In the corresponding script to run entry, type srdmail.cmd.
Set it running in background.
 */

parse arg mailfile
call replace_table

if RxfuncQuery('sysloadfuncs') <> 0 then
do
   Call RxFuncAdd 'SysLoadFuncs','RexxUtil','SysLoadFuncs'
   Call SysLoadFuncs
end

/* Check if SR/2 is installed on the machine */
srddir = value('srdprofiles', , 'os2environment')
if srddir = '' then exit

/* Parse out "From" and "Subject" lines */
call SysFileSearch 'From:', mailfile, fromfile.
call SysFileSearch 'Subject:', mailfile, subjectfile.
parse var fromfile.1 'From:' from
parse var subjectfile.1 'Subject:' subject
from = strip( from)
subject = strip( subject)


/* Convert "From" line to readable format */
from = convert( from)

/* Convert "Subject" line to readable format */
subject = convert( subject)

/* Keeps the from name without address if possible */
ch = substr( from, 1, 1)
if ch = '<' | ch = '(' then
do /* no real name, just the email address, keep it */
   from = translate( from, '    ', '<>()');
end
else do /* only keep the real name */
   charpos = lastpos('<', from)
   if charpos > 0 then
      from = delstr(from,charpos)
   else do
      charpos = lastpos('(', from)
      if charpos > 0 then
         from = delstr(from,1,charpos)
      end
   end

/* Re: -> 'reply of' */
if substr(subject,1,3) = 'Re:' then do
   subject = delstr(subject,1,3)
   subject = insert('reply of: ', subject)
end
/* but, sometimes it's "Re :" */
if substr(subject,1,4) = 'Re :' then do
   subject = delstr(subject,1,4)
   subject = insert('reply of: ', subject)
end

/* Fwd: -> 'forward of' */
if substr(subject,1,4) = 'Fwd:' then do
   subject = delstr(subject,1,4)
   subject = insert('forward of: ', subject)
end

/* Finds high priority messages */
highmsg = ''
call SysFileSearch 'priority: high', mailfile, dump
if dump.0 <> 0 then highmsg = 'high priority '


/* Fills missing entries */
if from='' then
        from='someone with no address'
if subject='' then
        subject='no subject'

        /* perform some translations to help srdspeak */
from = translate( from, '  ', ')"')
subject = translate( subject, '   ', ')"!')

/* Speak */
'@'srddir'\SRDSPEAK -s "You have received' highmsg 'e-mail from: ' from ' The subject is: ' subject'"'
exit


replace_table:

   acc.1 = '$'; rep.1 = ' dollar '
   acc.2 = '@'; rep.2 = ' at '
   max = 2
return


convert:

   parse arg line
   do j = 1 to max
      x = pos(acc.j, line)
      do while x > 0
         line = substr( line, 1, x-1) || rep.j || substr(line, x+length(acc.j))
         x = pos(acc.j, line)
      end
   end
return line
